@@ -1,4 +1,6 @@
 from investing_algorithm_framework.utils.version import get_version
+from investing_algorithm_framework.core.context import AlgorithmContext, \
+    AlgorithmContextInitializer
 from investing_algorithm_framework.core.data_providers import DataProvider, \
     RelationalDataProvider, ScheduledDataProvider
 from investing_algorithm_framework.core.strategies import Strategy
@@ -6,15 +8,18 @@ from investing_algorithm_framework.core.portfolio_managers import \
     AbstractPortfolioManager
 from investing_algorithm_framework.core.order_executors import \
     AbstractOrderExecutor
+from investing_algorithm_framework.core.utils import TimeUnit
 
-VERSION = (0, 2, 1, 'alpha', 0)
+VERSION = (0, 2, 2, 'alpha', 0)
 
 __all__ = [
     'get_version',
+    "AlgorithmContext",
     'DataProvider',
     'RelationalDataProvider',
     'ScheduledDataProvider',
     'Strategy',
     'AbstractPortfolioManager',
-    'AbstractOrderExecutor'
+    'AbstractOrderExecutor',
+    "AlgorithmContextInitializer"
 ]
