@@ -5,13 +5,26 @@ from investing_algorithm_framework.core.exceptions import OperationalException
 
 
 class AbstractPortfolioManager(ABC):
+    broker = None
 
-    def __init__(self, broker: str):
-        self._broker = broker
+    def __init__(self, broker: str = None):
 
-    @property
-    def broker(self):
-        return self._broker
+        if self.broker is None:
+            self.broker = broker
+
+        # If ID is none generate a new unique ID
+        if self.broker is None:
+            raise OperationalException(
+                "Portfolio manager has no broker specified"
+            )
+
+    def get_broker(self) -> str:
+        assert getattr(self, 'broker', None) is not None, (
+            "{} should either include a broker attribute, or override the "
+            "`get_broker()`, method.".format(self.__class__.__name__)
+        )
+
+        return getattr(self, 'broker')
 
     @abstractmethod
     def get_portfolio_size(self, algorithm_context: AlgorithmContext) -> float:
